@@ -16,13 +16,13 @@ test_that("nldi basics work", {
 
   expect_equal(length(discover_nldi_navigation(nldi_nwis)), 4)
 
-  expect_equal(length(discover_nldi_navigation(nldi_nwis, tier = "test")), 4)
+  # expect_equal(length(discover_nldi_navigation(nldi_nwis, tier = "test")), 4)
 
   expect_error(discover_nldi_navigation(nldi_nwis, tier = "borked"),
                "only prod or test allowed.")
 
   expect_error(discover_nldi_navigation(nldi_nwis[1]),
-                 "Missing some required input for NLDI. Expected: featureID")
+                 "Missing some required input for NLDI. Expected length 2 character vector or list with optional names: featureID")
 
 })
 
@@ -49,10 +49,19 @@ test_that("navigation works", {
 
   expect_true(nrow(nav2) > nrow(nav))
 
-  expect_equal(navigate_nldi(list(featureSource = "wqp",
-                                  featureID = "TCEQMAIN-16638"),
-                             mode = "upstreamMain",
-                             data_source = "nwissite"), dplyr::tibble())
+  nldi_nwis <- as.character(nldi_nwis)
+
+  nav3 <- navigate_nldi(nldi_feature = nldi_nwis,
+                        mode = "upstreamMain",
+                        data_source = "flowline",
+                        distance_km = 10)
+
+  expect_is(sf::st_geometry(nav3), "sfc_LINESTRING")
+
+  # expect_equal(navigate_nldi(list(featureSource = "wqp",
+  #                                 featureID = "TCEQMAIN-16638"),
+  #                            mode = "upstreamMain",
+  #                            data_source = "nwissite"), dplyr::tibble())
 })
 
 test_that("basin works", {
@@ -68,3 +77,20 @@ test_that("basin works", {
   expect_true("sfc_POLYGON" %in% class(sf::st_geometry(nav)),
          "expected polygon response")
 })
+
+test_that("get feature works", {
+  skip_on_cran()
+
+  f <- get_nldi_feature(list(featureSource = "nwissite", featureID = "USGS-05428500"))
+
+  expect_equal(nrow(f), 1)
+  expect_equal(ncol(f), 8)
+  expect_equal(f$identifier, "USGS-05428500")
+
+  f <- get_nldi_feature(list("nwissite", "USGS-05428500"))
+
+  expect_equal(nrow(f), 1)
+  expect_equal(ncol(f), 8)
+  expect_equal(f$identifier, "USGS-05428500")
+
+})
